@@ -749,6 +749,12 @@ func (m *Manager) ConfirmRollback(sender dbus.Sender, confirm bool) *dbus.Error
 			if err != nil {
 				logger.Warning(err)
 			}
+			if m.grub != nil {
+				err = m.grub.changeGrubDefaultEntry(normalBootEntry)
+				if err != nil {
+					logger.Warning(err)
+				}
+			}
 			m.PowerOff(sender, true)
 		}()
 	} else {
@@ -757,6 +763,7 @@ func (m *Manager) ConfirmRollback(sender dbus.Sender, confirm bool) *dbus.Error
 	return nil
 }
 
-func (m *Manager) CanRollback() (bool, *dbus.Error) {
-	return osTreeCanRollback(), nil
+func (m *Manager) CanRollback() (bool, string, *dbus.Error) {
+	can, info := osTreeCanRollback()
+	return can, info, nil
 }
