@@ -112,6 +112,11 @@ func (m *Manager) distUpgradePartly(sender dbus.Sender, origin system.UpdateType
 			inhibit(false)
 			return nil
 		},
+		string(system.RunningStatus): func() error {
+			logger.Info("DistUpgradePartly:run wrap running hook")
+			inhibit(true)
+			return nil
+		},
 	})
 	m.updateJobList()
 	// 将job的状态修改为pause,并添加到队列中,但是不开始
@@ -122,10 +127,9 @@ func (m *Manager) distUpgradePartly(sender dbus.Sender, origin system.UpdateType
 		return "", dbusutil.ToError(err)
 	}
 	m.inhibitAutoQuitCountAdd() // 开始备份前add，结束备份后sub(无论是否成功)
-	inhibit(true)
 	var isExist bool
 	var backupJob *Job
-	if needBackup {
+	if needBackup && system.NormalFileExists(DEEPIN_IMMUTABLE_CTL) {
 		isExist, backupJob, err = m.jobManager.CreateJob("", system.BackupType, nil, nil, nil)
 		if isExist {
 			return "", dbusutil.ToError(JobExistError)
@@ -133,19 +137,18 @@ func (m *Manager) distUpgradePartly(sender dbus.Sender, origin system.UpdateType
 		backupJob.next = upgradeJob
 		backupJob.setPreHooks(map[string]func() error{
 			string(system.RunningStatus): func() error {
+				inhibit(true)
 				m.statusManager.SetABStatus(mode, system.BackingUp, system.NoABError)
 				return nil
 			},
-			string(system.EndStatus): func() error {
-				logger.Info("OsBackup: run end hook")
-				return nil
-			},
 			string(system.SucceedStatus): func() error {
 				m.statusManager.SetABStatus(mode, system.HasBackedUp, system.NoABError)
+				inhibit(false)
 				return nil
 			},
 			string(system.FailedStatus): func() error {
 				m.statusManager.SetABStatus(mode, system.BackupFailed, system.OtherError)
+				inhibit(false)
 				msg := gettext.Tr("Backup failed!")
 				action := []string{"backup", gettext.Tr("Back Up Again"), "continue", gettext.Tr("Proceed to Update")}
 				hints := map[string]dbus.Variant{
@@ -158,8 +161,7 @@ func (m *Manager) distUpgradePartly(sender dbus.Sender, origin system.UpdateType
 			},
 		})
 		backupJob.setAfterHooks(map[string]func() error{
-			string(system.EndStatus): func() error {
-				inhibit(false)
+			string(system.SucceedStatus): func() error {
 				startJobErr = startUpgrade()
 				if startJobErr != nil {
 					logger.Warning(err)
@@ -176,7 +178,6 @@ func (m *Manager) distUpgradePartly(sender dbus.Sender, origin system.UpdateType
 	defer func() {
 		// 没有开始更新提前结束时，需要处理抑制锁和job
 		if startJobErr != nil {
-			inhibit(false)
 			err = m.CleanJob(upgradeJob.Id)
 			if err != nil {
 				logger.Warning(err)
@@ -558,10 +559,8 @@ func osTreeCmd(args []string) (out string, err error) {
 			return stdout.String(), nil
 		}
 	} else {
-		logger.Warningf("%v not found", DEEPIN_IMMUTABLE_CTL)
-		return "", nil
+		return "", fmt.Errorf("%v not found", DEEPIN_IMMUTABLE_CTL)
 	}
-	return
 }
 
 type ostreeError struct {
@@ -572,6 +571,8 @@ type ostreeError struct {
 type ostreeRollbackData struct {
 	Version     int  `json:"version"`
 	CanRollback bool `json:"can_rollback"`
+	//Time        int64  `json:"time"`
+	//Name        string `json:"name"`
 }
 
 type ostreeResponse struct {
@@ -605,11 +606,11 @@ func osTreeRollback() error {
 	return nil
 }
 
-func osTreeCanRollback() bool {
+func osTreeCanRollback() (bool, string) {
 	out, err := osTreeCmd([]string{"admin", "rollback", "--can-rollback", "-j"})
 	if err != nil {
 		logger.Warning(err)
-		return false
+		return false, ""
 	}
 	logger.Info(out)
 	var resp ostreeResponse
@@ -619,11 +620,11 @@ func osTreeCanRollback() bool {
 		if err = json.Unmarshal(resp.Data, &data); err != nil {
 			logger.Warning(err)
 		}
-		return data.CanRollback
+		return data.CanRollback, string(resp.Data)
 	} else {
 		logger.Warning("ostree Unmarshal data failed", err)
 	}
-	return false
+	return false, ""
 }
 
 func (m *Manager) preUpgradeCmdSuccessHook(job *Job, needChangeGrub bool, mode system.UpdateType, uuid string) error {
